import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { Input, Spin } from 'antd';
import { debounce } from 'lodash';
import { getCert, init, sign } from '../../utils/uca';

class UCA extends Component {

  constructor(props, context) {
    super(props, context);
    this.state = {
      ready: false,
    };
  }

  componentDidMount() {
    this.task = setInterval(() => {
      const res = init();
      if (res === 0) {
        clearInterval(this.task);
        this.task = null;
        this.setState({
          ready: true,
        });
      }
    }, 300);
  }

  componentWillUnmount() {
    if (this.task) {
      clearInterval(this.task);
    }
  }

  onChange = (value) => {
    if (this.state.ready && this.props.onChange) {
      if (value) {
        if (this.props.data) {
          this.props.onChange(sign(value, this.props.data));
        } else {
          this.props.onChange(getCert(value));
        }
      }
    }
  };
  render() {
    const onChange = (e) => {
      return debounce(this.onChange, 300)(e.target.value);
    };
    const { loading, ...rest } = this.props;
    return (
      <Spin spinning={!this.state.ready && loading} size="small">
        <Input {...rest} onChange={onChange} type="password" />
      </Spin>
    );
  }
}

UCA.propTypes = {
  loading: PropTypes.bool,
  data: PropTypes.string,
};

UCA.defaultProps = {
  loading: false,
};

export default UCA;
